/*
    LogExport: Export Symbian call log to a file
	Copyright (C) 2007 Yohanes Nugroho

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/*
============================================================================
 Name        : LogExportAppUi.h
 Author      : Yohanes Nugroho
 Copyright   : Yohanes Nugroho
 Description : Declares UI class for application.
============================================================================
*/

#ifndef __LOGEXPORTAPPUI_h__
#define __LOGEXPORTAPPUI_h__

// INCLUDES
#include <aknappui.h>
#include <aknprogressdialog.h> 

// FORWARD DECLARATIONS
class CLogExportAppView;
class CLogWriter;

// CLASS DECLARATION
/**
* CLogExportAppUi application UI class.
* Interacts with the user through the UI and request message processing
* from the handler class
*/
class CLogExportAppUi : public CAknAppUi, public MProgressDialogCallback
    {
    public: // Constructors and destructor

        /**
        * ConstructL.
        * 2nd phase constructor.
        */
        void ConstructL();

        /**
        * CLogExportAppUi.
        * C++ default constructor. This needs to be public due to
        * the way the framework constructs the AppUi
        */
        CLogExportAppUi();

        /**
        * ~CLogExportAppUi.
        * Virtual Destructor.
        */
        virtual ~CLogExportAppUi();

    private:  // Functions from base classes

        /**
        * From CEikAppUi, HandleCommandL.
        * Takes care of command handling.
        * @param aCommand Command to be handled.
        */
        void HandleCommandL( TInt aCommand );

        /**
        *  HandleStatusPaneSizeChange.
        *  Called by the framework when the application status pane
 		*  size is changed.
        */

		void HandleStatusPaneSizeChange();
		
		void DoExport();
		void DialogDismissedL  (  TInt    );
        
    private: // Data

        /**
        * The application view
        * Owned by CLogExportAppUi
        */
        CLogExportAppView* iAppView;
		CLogWriter *iLogWriter;
		TBool iExportDone;
        
        
    };

#endif // __LOGEXPORTAPPUI_h__

// End of File
