/*
    LogExport: Export Symbian call log to a file
	Copyright (C) 2007 Yohanes Nugroho

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/*
============================================================================
 Name        : LogExportAppUi.cpp
 Author      : Yohanes Nugroho
 Copyright   : Yohanes Nugroho
 Description : CLogExportAppUi implementation
============================================================================
*/

// INCLUDE FILES
#include <avkon.hrh>
#include <aknnotewrappers.h>
#include <stringloader.h>
#include <LogExport.rsg>
#include <f32file.h>
#include <s32file.h>
#include <aknwaitdialog.h> 
#include <akncommondialogs.h> 

#include "LogExport.pan"
#include "LogExportAppUi.h"
#include "LogExportAppView.h"
#include "LogExport.hrh"
#include "LogWriter.h"


_LIT( KFileName, "C:\\private\\A0001C61\\LogExport.txt" );
_LIT( KText, "Hello World!");

// ============================ MEMBER FUNCTIONS ===============================


// -----------------------------------------------------------------------------
// CLogExportAppUi::ConstructL()
// Symbian 2nd phase constructor can leave.
// -----------------------------------------------------------------------------
//
void CLogExportAppUi::ConstructL()
    {
    // Initialise app UI with standard value.
    BaseConstructL();

	// Create view object
	iAppView = CLogExportAppView::NewL( ClientRect() );
					iLogWriter = new CLogWriter();
					iLogWriter->ConstructL();

	}
// -----------------------------------------------------------------------------
// CLogExportAppUi::CLogExportAppUi()
// C++ default constructor can NOT contain any code, that might leave.
// -----------------------------------------------------------------------------
//
CLogExportAppUi::CLogExportAppUi()
    {
    // No implementation required
    }

// -----------------------------------------------------------------------------
// CLogExportAppUi::~CLogExportAppUi()
// Destructor.
// -----------------------------------------------------------------------------
//
CLogExportAppUi::~CLogExportAppUi()
    {
    if ( iAppView )
        {
        delete iAppView;
        iAppView = NULL;
        }
	if (iLogWriter) {
		iLogWriter->Cancel();
		delete iLogWriter;
	}
	
    }

	
void CLogExportAppUi::DoExport()
{
	
	TTime now;
	now.HomeTime();
	TFileName c;	
	now.FormatL(c, _L("c:\\data\\log-%F%Y-%M-%D.csv"));
	if (AknCommonDialogs::RunSaveDlgLD(c, R_MEM)) {
		iLogWriter->Export(c);
	}
}	
	
void CLogExportAppUi::DialogDismissedL  (  TInt    )
{
	iExportDone = ETrue;
}	
	
// -----------------------------------------------------------------------------
// CLogExportAppUi::HandleCommandL()
// Takes care of command handling.
// -----------------------------------------------------------------------------
//
void CLogExportAppUi::HandleCommandL( TInt aCommand )
    {
    switch( aCommand )
        {
        case EEikCmdExit:
        case EAknSoftkeyExit:
		{
            Exit();
            break;
		}
        case ECommand1:
            {

				DoExport();
			
            }
            break;
		case ECommand2:
			{
			}
			break;
        default:
            Panic( ELogExportUi );
            break;
        }
    }
// -----------------------------------------------------------------------------
//  Called by the framework when the application status pane
//  size is changed.  Passes the new client rectangle to the
//  AppView
// -----------------------------------------------------------------------------
//
void CLogExportAppUi::HandleStatusPaneSizeChange()
{
	iAppView->SetRect( ClientRect() );
	
} 

// End of File
