/*
    LogExport: Export Symbian call log to a file
	Copyright (C) 2007 Yohanes Nugroho

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/*
============================================================================
 Name        : LogExportDocument.cpp
 Author      : Yohanes Nugroho
 Copyright   : Yohanes Nugroho
 Description : CLogExportDocument implementation
============================================================================
*/


// INCLUDE FILES
#include "LogExportAppUi.h"
#include "LogExportDocument.h"

// ============================ MEMBER FUNCTIONS ===============================

// -----------------------------------------------------------------------------
// CLogExportDocument::NewL()
// Two-phased constructor.
// -----------------------------------------------------------------------------
//
CLogExportDocument* CLogExportDocument::NewL( CEikApplication&
                                                          aApp )
    {
    CLogExportDocument* self = NewLC( aApp );
    CleanupStack::Pop( self );
    return self;
    }

// -----------------------------------------------------------------------------
// CLogExportDocument::NewLC()
// Two-phased constructor.
// -----------------------------------------------------------------------------
//
CLogExportDocument* CLogExportDocument::NewLC( CEikApplication&
                                                           aApp )
    {
    CLogExportDocument* self =
        new ( ELeave ) CLogExportDocument( aApp );

    CleanupStack::PushL( self );
    self->ConstructL();
    return self;
    }

// -----------------------------------------------------------------------------
// CLogExportDocument::ConstructL()
// Symbian 2nd phase constructor can leave.
// -----------------------------------------------------------------------------
//
void CLogExportDocument::ConstructL()
    {
    // No implementation required
    }

// -----------------------------------------------------------------------------
// CLogExportDocument::CLogExportDocument()
// C++ default constructor can NOT contain any code, that might leave.
// -----------------------------------------------------------------------------
//
CLogExportDocument::CLogExportDocument( CEikApplication& aApp )
    : CAknDocument( aApp )
    {
    // No implementation required
    }

// ---------------------------------------------------------------------------
// CLogExportDocument::~CLogExportDocument()
// Destructor.
// ---------------------------------------------------------------------------
//
CLogExportDocument::~CLogExportDocument()
    {
    // No implementation required
    }

// ---------------------------------------------------------------------------
// CLogExportDocument::CreateAppUiL()
// Constructs CreateAppUi.
// ---------------------------------------------------------------------------
//
CEikAppUi* CLogExportDocument::CreateAppUiL()
    {
    // Create the application user interface, and return a pointer to it;
    // the framework takes ownership of this object
    return ( static_cast <CEikAppUi*> ( new ( ELeave )
                                        CLogExportAppUi ) );
    }

// End of File
